@@ -1,6 +1,8 @@
-# -*- coding: utf8 -*-
+# -*- coding: utf-8 -*-
 import time
 
+import mock
+
 from django.contrib.auth import authenticate
 from django.test import Client
 from django.http import Http404
@@ -12,6 +14,8 @@ from django_nopassword import views
 from django_nopassword.models import LoginCode
 from django_nopassword.utils import User
 
+from .models import NoUsernameUser
+
 
 class TestLoginCodes(unittest.TestCase):
     def setUp(self):
@@ -45,6 +49,19 @@ class TestLoginCodes(unittest.TestCase):
         self.inactive_user.delete()
 
 
+class AuthenticationBackendTests(unittest.TestCase):
+
+    def test_authenticate_with_custom_user_model(self):
+        """When a custom user model is used that doesn't have a field
+        called "username" return `None`
+        """
+
+        with mock.patch('django_nopassword.backends.User', new=NoUsernameUser):
+            result = authenticate(username='username')
+
+            self.assertIsNone(result)
+
+
 class TestViews(unittest.TestCase):
 
     def setUp(self):
@@ -105,4 +122,4 @@ class TestUsersJsonView(unittest.TestCase):
     def test_200(self):
         request = self.factory.get('/accounts/users.json')
         response = views.users_json(request)
-        self.assertEqual(response.status_code, 200)
\ No newline at end of file
+        self.assertEqual(response.status_code, 200)
